@@ -677,7 +677,8 @@ test_that("Independent of root position", {
   
   Test(MASTSize, 8L, rooted = FALSE)
   # Tested further for NNIDist in test-tree_distance_nni.R
-  Test(NNIDist, c(lower = 0, tight_upper = 0, loose_upper = 0))
+  Test(NNIDist, c(lower = 0, best_lower = 0, tight_upper = 0, best_upper = 0,
+                  loose_upper = 0, fack_upper = 0, li_upper = 0))
   Test(SPRDist, c(spr = 0))
   
 })
